@@ -10,6 +10,10 @@ exports.files = [
 	"CSSStyleSheet",
 	"CSSKeyframesRule",
 	"CSSKeyframeRule",
+	"MatcherList",
+	"CSSDocumentRule",
+	"CSSValue",
+	"CSSValueExpression",
 	"parse",
 	"clone"
 ];
